@@ -33,7 +33,8 @@ public slots:
 
                     m << "unlocked";
                     QDBusConnection::systemBus().send(m);
-                    sleep(60);
+                    int to = getTimeout();
+                    sleep(to);
                     ps.kill();
                 }
 
@@ -41,6 +42,27 @@ public slots:
 	
         file.close();
     }
+
+  int getTimeout()
+  {
+      int sto = -1;
+      QFile file("/home/user/.proximityclock/.timeout");
+      if (file.open(QIODevice::ReadOnly))
+      {
+          while (!file.atEnd()) {
+              QString line = file.readLine();
+
+              QStringList list1 = line.split("=");
+
+              sto = list1[1].toInt();
+          }
+      }
+
+      file.close();
+
+      if ( sto == -1 ) return 60;
+      else return sto;
+  }
 };
 
 int main ( int argc, char *argv[] )
